@@ -1,4 +1,4 @@
-/* $Id: sysdeps.h,v 1.35 2004/12/06 14:44:10 bdejean Exp $ */
+/* $Id: sysdeps.h,v 1.37 2005/06/07 09:54:43 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -52,8 +52,9 @@ G_BEGIN_DECLS
 #define GLIBTOP_SYSDEPS_NETLOAD		21
 #define GLIBTOP_SYSDEPS_PPP		22
 #define GLIBTOP_SYSDEPS_NETLIST		23
+#define GLIBTOP_SYSDEPS_PROC_OPEN_FILES	24
 
-#define GLIBTOP_MAX_SYSDEPS		24
+#define GLIBTOP_MAX_SYSDEPS		25
 
 #define GLIBTOP_SYSDEPS_ALL		((1 << GLIBTOP_MAX_SYSDEPS) - 1)
 
@@ -85,6 +86,7 @@ struct _glibtop_sysdeps
 		proc_segment,		/* glibtop_proc_segment	*/
 		proc_args,		/* glibtop_proc_args	*/
 		proc_map,		/* glibtop_proc_map	*/
+		proc_open_files,	/* glibtop_proc_open_files */
 		mountlist,		/* glibtop_mountlist	*/
 		fsusage,		/* glibtop_fsusage	*/
 		netlist,		/* glibtop_netlist	*/
@@ -92,8 +94,7 @@ struct _glibtop_sysdeps
 		ppp;			/* glibtop_ppp		*/
 };
 
-#define glibtop_get_sysdeps(sysdeps)	glibtop_get_sysdeps_r(glibtop_global_server,sysdeps)
-
+void glibtop_get_sysdeps (glibtop_sysdeps *buf);
 void glibtop_get_sysdeps_r (glibtop *server, glibtop_sysdeps *buf);
 
 
